@@ -1,6 +1,6 @@
 /* Bluefish HTML Editor
  *
- * Copyright (C) 1999-2002 Olivier Sessink
+ * Copyright (C) 1999-2004 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,8 @@
 #ifndef __GTK_EASY_H_
 #define __GTK_EASY_H_
 
+#define FILE_CHOOSER_USE_VFS(dialog) (g_object_set_data(G_OBJECT(dialog),"GnomeFileSelectorEnableVFS",GINT_TO_POINTER(1)))
+
 /* GtkWindowPosition can be 
 GTK_WIN_POS_NONE
 GTK_WIN_POS_CENTER
@@ -44,6 +46,8 @@ gpointer progress_popup(GtkWidget *win,gchar *title, guint maxvalue);
 void progress_destroy(gpointer gp);
 
 void setup_toggle_item(GtkItemFactory * ifactory, gchar * path, gint state);
+#define setup_toggle_item_from_widget(var1, var2, var3) setup_toggle_item(gtk_item_factory_from_widget(var1), var2, var3)
+#define menuitem_set_sensitive(menubar, path, state) gtk_widget_set_sensitive(gtk_item_factory_get_widget(gtk_item_factory_from_widget(menubar), path), state)
 void string_apply(gchar ** config_var, GtkWidget * entry);
 void integer_apply(gint *config_var, GtkWidget * widget, gboolean is_checkbox);
 GtkWidget *combo_with_popdown(const gchar * setstring, GList * which_list, gint editable);
@@ -86,16 +90,21 @@ GtkWidget *bf_gtkstock_button(const gchar * stock_id, GCallback func, gpointer f
 GtkWidget *bf_generic_frame_new(const gchar *label, GtkShadowType shadowtype, gint borderwidth);
 void bf_mnemonic_label_tad_with_alignment(const gchar *labeltext, GtkWidget *m_widget, gfloat xalign, gfloat yalign, 
 						GtkWidget *table, guint left_attach, guint right_attach, guint top_attach, guint bottom_attach);
+GtkWidget *bf_label_with_markup(const gchar *labeltext);
 void bf_label_tad_with_markup(const gchar *labeltext, gfloat xalign, gfloat yalign,
 								GtkWidget *table, guint left_attach, guint right_attach, guint top_attach, guint bottom_attach);						
 GtkWidget *file_but_new(GtkWidget * which_entry, gint full_pathname, Tbfwin *bfwin);
+#ifdef HAVE_ATLEAST_GTK_2_4
+GtkWidget * file_chooser_dialog(Tbfwin *bfwin, gchar *title, GtkFileChooserAction action, 
+											gchar *set, gboolean localonly, gboolean multiple, const gchar *filter);
+#else
 void close_modal_window_lcb(GtkWidget * widget, gpointer window);
 gchar *return_file_w_title(gchar * setfile, gchar *title);
 gchar *return_file(gchar * setfile);
 GList *return_files_w_title(gchar * setfile, gchar *title);
 GList *return_files(gchar * setfile);
 gchar *return_dir(gchar *setdir, gchar *title);
-
+#endif
 void destroy_disposable_menu_cb(GtkWidget *widget, GtkWidget *menu);
 
 #ifndef HAVE_ATLEAST_GTK_2_2
